/* this is the container for the pages */
.wy-nav-content {
    max-width: 100%;
    padding: 0px 40px 0px 0px;
    margin-top: 0px;
}

.wy-nav-content-wrap {
    border-right: solid 1px;
}

div.rst-content {
    max-width: 1300px;
    border: 0;
    padding: 10px 80px 10px 80px;
    margin-left: 50px;
}

@media (max-width: 768px) {
    div.rst-content {
        max-width: 1300px;
        border: 0;
        padding: 0px 10px 10px 10px;
        margin-left: 0px;
    }
}
